@@ -1,6 +1,7 @@
 from sqlalchemy import create_engine
 from sqlalchemy import text
 from urllib.parse import quote_plus as urlquote
+import re
 
 
 # 数据已存在时的操作
@@ -65,8 +66,8 @@ class DBManager(object):
         try:
             session = self.engine.connect()
             result = session.execute(sql)
-            hasResult = 'select' in sql.lower()
-            if hasResult:
+            find = re.search(r'^select', sql.lower().strip())
+            if find:
                 rows = result.fetchall()
                 return rows
         except Exception as e:
