@@ -84,6 +84,15 @@ def saveData(obj, fullpath):
     saveFile(jobj(obj), fullpath)
 
 
+def loadData(fullpath):
+    with open(fullpath, 'r') as file:
+        content = file.read()
+    try:
+        return json.loads(content)
+    except Exception as e:
+        return []
+
+
 def requestJson(url):
     text = requests.get(url).text
     return json.loads(text)
@@ -208,6 +217,27 @@ def get_files(dir):
     return arr
 
 
+class Progress(object):
+
+    _flag = 0
+
+    @classmethod
+    def go(cls, idx, n, msg='', delta=0):
+        index = idx + 1
+        scale = 1
+        if n > 1000:
+            scale = 100
+        percent = index / n * 100 * scale
+        if percent >= cls._flag or index == n:
+            cls._flag = cls._flag + delta
+            length = len(str(scale))-1
+            fmt = '%6.'+str(length)+'f%% - %4d/%4d'
+            string = fmt % (percent/scale, index, n), msg
+            if index == n:
+                cls._flag = 0
+            print(*string)
+
+
 class Retry(object):
     def __init__(self, func, args=(), retry=3, delay=1, default=None):
         """
@@ -243,4 +273,8 @@ if __name__ == '__main__':
     # print(date_str())
     # r = reg_find(r'\[\W*\d{4}\W*(\,\W*\d{4}\W*)*\W*\]', 'asdf[2022 , 1002,3040,3030,1100,2323]asd')
     # print(r)
+
+    # for i in range(5000):
+    #     Progress.go(i, 5000, 'this is no. %s data' % i)
+    
     pass
